@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 """
 @author: LiangChao
-@email：kevinleong1011@hotmail.com
+@email：liang20201101@163.com
 @desc: 
 """
 import inspect
@@ -39,9 +39,8 @@ def serialize(o, fields=None, exclude_fields=None, dt_fmt=const.DEFAULT_TIME_FOR
             continue
         elif name.startswith('_'):
             continue
-        if exclude_fields:
-            if name in exclude_fields:
-                continue
+        if exclude_fields and name in exclude_fields:
+            continue
         if fields:
             for f in fields:
                 if isinstance(f, dict):
