@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 """
 @author: LiangChao
-@email：kevinleong1011@hotmail.com
+@email：liang20201101@163.com
 @desc: 
 """
 import os
