@@ -2,12 +2,16 @@
 
 """
 @Author: LiangChao
-@Email: kevinleong1011@hotmail.com
+@Email: liang20201101@163.com
 @Created: 2022/1/9
 @Desc: 
 """
+import warnings
+
+from deprecated.sphinx import deprecated
 
 
+@deprecated(version='1.0.5', reason='Please use List instead')
 def remove(lst, item, raise_error=False):
     """
     移除元素
@@ -16,6 +20,7 @@ def remove(lst, item, raise_error=False):
     :param raise_error: 是否抛出异常
     :return:
     """
+    warnings.warn("This will be removed at v1.0.6.", DeprecationWarning)
     try:
         lst.remove(item)
     except ValueError:
