@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 """
 @author: LiangChao
-@email：kevinleong1011@hotmail.com
+@email：liang20201101@163.com
 @desc: 
 """
 import fnmatch
@@ -11,7 +11,9 @@ import os
 import re
 import shutil
 import sys
+import warnings
 from datetime import datetime
+from functools import cached_property
 
 
 def name(filename):
@@ -207,11 +209,22 @@ class Path(str):
     def __new__(cls, o, *args, **kwargs):  # 重写 __new__ 否则无法正常重写 __init__
         return super().__new__(cls, o)
 
-    @property
+    @cached_property
+    def name(self):
+        """
+        名称，不带后缀
+        :return:
+        """
+        if self.isfile:
+            return self.basename.rsplit('.', maxsplit=1)[0]
+        else:
+            return self.basename
+
+    @cached_property
     def basename(self) -> str:
         return os.path.basename(self)
 
-    @property
+    @cached_property
     def extension(self):
         basename = self.basename
         try:
@@ -222,22 +235,25 @@ class Path(str):
 
     @property
     def pure_name(self):
+        warnings.warn('过期，请使用属性name')
         return self.basename.rsplit('.', maxsplit=1)[0]
 
     @property
     def name_without_extension(self):
         """名称（不包含扩展名）"""
+        warnings.warn('过期，请使用属性name')
         return self.basename.rsplit('.', maxsplit=1)[0]
 
     @property
     def name_no_ext(self):
+        warnings.warn('过期，请使用属性name')
         return self.basename.rsplit('.', maxsplit=1)[0]
 
     @property
     def size(self):
         return os.path.getsize(self)
 
-    @property
+    @cached_property
     def create_time(self):
         return datetime.fromtimestamp(os.path.getctime(self))
 
@@ -249,20 +265,20 @@ class Path(str):
     def last_access_time(self):
         return datetime.fromtimestamp(os.path.getatime(self))
 
-    @property
+    @cached_property
     def isfile(self):
         return os.path.isfile(self)
 
-    @property
+    @cached_property
     def isdir(self):
         return os.path.isdir(self)
 
-    @property
+    @cached_property
     def ismount(self):
         """是否盘符"""
         return os.path.ismount(self)
 
-    @property
+    @cached_property
     def parent(self):
         return self.__class__(os.path.dirname(self)) if not self.ismount else None
 
@@ -333,14 +349,23 @@ class Path(str):
                 if pattern is None or (pattern and fnmatch.fnmatch(file, pattern)):
                     yield file, self.__class__(root) / file
 
+    # def walk(self, pattern=None):
+    #     for root, dirs, files in os.walk(self):
+    #         for d in dirs:
+    #             if pattern is None or (pattern and fnmatch.fnmatch(d, pattern)):
+    #                 yield d, self.__class__(root) / d, 'dir'
+    #         for file in files:
+    #             if pattern is None or (pattern and fnmatch.fnmatch(file, pattern)):
+    #                 yield file, self.__class__(root) / file, 'file'
+
     def walk(self, pattern=None):
         for root, dirs, files in os.walk(self):
             for d in dirs:
                 if pattern is None or (pattern and fnmatch.fnmatch(d, pattern)):
-                    yield d, self.__class__(root) / d, 'dir'
+                    yield self.__class__(root) / d
             for file in files:
                 if pattern is None or (pattern and fnmatch.fnmatch(file, pattern)):
-                    yield file, self.__class__(root) / file, 'file'
+                    yield self.__class__(root) / file
 
     def reserve_search(self, pattern):
         """
@@ -416,7 +441,9 @@ class Path(str):
         :param new: new name
         :return:
         """
-        shutil.move(self, os.path.join(self.parent, new))
+        new_path = os.path.join(self.parent, new)
+        shutil.move(self, new_path)
+        return Path(new_path)
 
     @staticmethod
     def abspath(rel_path: str, base_dir=None):
@@ -445,7 +472,7 @@ class Path(str):
         return Path(os.sep.join(cur_dir_parts))
 
     def join(self, *paths):
-        return join(self, *paths)
+        return os.path.join(self, *paths)
 
     def expend(self, *paths):
         result = self
