@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 """
 @author: LiangChao
-@email：liangchao@noboauto.com
+@email：liang20201101@163.com
 @desc: 对platform进行扩展，同时可以直接调用原有方法
 """
 import platform
