@@ -2,11 +2,14 @@
 
 """
 @Author: LiangChao
-@Email: kevinleong1011@hotmail.com
+@Email: liang20201101@163.com
 @Desc: 
 """
+import inspect
 import os
+import re
 import sys
+from functools import cached_property
 
 from .ospath import Path
 
@@ -117,3 +120,44 @@ def parse_obj(name: str, raise_error=True):
     if not o and raise_error:
         raise ModuleNotFoundError(module_name)
     return o
+
+
+def iter_module(module, private=False, public=True, func_only=False, cls_only=False):
+    for name in dir(module):
+        member = getattr(module, name)
+        if private and hasattr(member, '__module__') and member.__module__ != module.__name__:
+            continue  # 非本模块内定义的不包括在内
+        if public and name.startswith('_'):
+            continue
+        if func_only and not inspect.isfunction(member):
+            continue
+        if cls_only and not inspect.isclass(member):
+            continue
+        yield name, member
+
+
+def fullname(o):
+    """
+    获取python对象的全名
+    :param o:
+    :return:
+    """
+
+
+class PyObject:
+    def __init__(self, o):
+        self._o = o
+
+    @cached_property
+    def fullname(self):
+        if inspect.ismodule(self._o):
+            return self._o.__name__
+        module = inspect.getmodule(self._o)
+        if inspect.isclass(self._o):
+            return f'{module.__name__}.{self._o.__name__}'
+        if inspect.isroutine(self._o):
+            if inspect.isfunction(self._o):
+                name = re.search(r'<function (\S+) at', str(self._o)).groups()[0]
+            else:
+                name = re.search(r'<bound method (\S+) of', str(self._o)).groups()[0]
+            return f'{module.__name__}.{name}'
