@@ -2,13 +2,16 @@
 
 """
 @Author: LiangChao
-@Email: kevinleong1011@hotmail.com
+@Email: liang20201101@163.com
 @Desc: 
 """
+import asyncio
+import queue
 import threading
 import time
 import traceback
 import uuid
+from asyncio import Future, CancelledError
 from concurrent.futures.thread import ThreadPoolExecutor
 from datetime import datetime
 from typing import List, Optional
@@ -386,6 +389,82 @@ class TaskPool:
                 yield task
 
 
+class AsyncTaskPool:
+    """
+    异步任务池
+    """
+
+    def __init__(self, loop=None, max_size=5):
+        self.loop = loop or asyncio.new_event_loop()
+        self.queue = queue.Queue(max_size)
+        self.loop_thread = None
+        self._running = False
+        self._stop = False
+        self._force_stop = False
+
+    @property
+    def running(self):
+        return self._running
+
+    def _start_thread_loop(self):
+        asyncio.set_event_loop(self.loop)
+        self.loop.run_forever()
+
+    def run_tasks(self):
+        while True:
+            if self._force_stop:
+                self.stop_thread_loop()
+            if self._stop:
+                break
+            if self.queue.empty():
+                continue
+            func, callback = self.queue.get()
+            future = asyncio.run_coroutine_threadsafe(func, self.loop)
+
+            def callback_done(_future: Future):
+                try:
+                    if callback and not _future.cancelled():
+                        callback(_future.result())
+                except CancelledError:
+                    pass
+                finally:
+                    pass
+
+            future.add_done_callback(callback_done)
+
+    def stop(self, force=False):
+        self._stop = True
+        if force:
+            self._force_stop = True
+
+    def start_thread_loop(self):
+        self._running = True
+        self.loop_thread = threading.Thread(target=self._start_thread_loop)
+        self.loop_thread.daemon = True
+        self.loop_thread.start()
+        thread = threading.Thread(target=self.run_tasks)  # 负责开启任务携程
+        thread.daemon = True
+        thread.start()
+
+    def stop_thread_loop(self):
+        async def _close_thread_loop():
+            while True:
+                if self.queue.empty():
+                    self.loop.stop()
+                    break
+                await asyncio.sleep(1)
+
+        asyncio.run_coroutine_threadsafe(_close_thread_loop(), self.loop)
+
+    def submit(self, func, callback=None):
+        if not self._running:
+            self.start_thread_loop()
+        self.queue.put((func, callback))
+
+    def release(self):
+        self.stop_thread_loop()
+
+
 class TaskError(Exception):
     """"""
 
