@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 """
 @author: LiangChao
-@email：liangchao@noboauto.com
+@email：liang20201101@163.com
 @desc: 
 """
 import string
@@ -10,6 +10,10 @@ import uuid
 
 
 def short_id():
+    """
+    生成短ID
+    :return:
+    """
     s = str(uuid.uuid4()).replace("-", '')  # 注意这里需要用uuid4
     buffer = []
     chars = string.digits + string.ascii_letters
